@@ -222,7 +222,7 @@ public class Merlin extends CryptoBase {
             keyStoreLocation = keyStoreLocation.trim();
 
             try (InputStream is = loadInputStream(loader, keyStoreLocation)) {
-                String passwd = properties.getProperty(prefix + KEYSTORE_PASSWORD, "security");
+                String passwd = properties.getProperty(prefix + KEYSTORE_PASSWORD);
                 if (passwd != null) {
                     passwd = passwd.trim();
                     passwd = decryptPassword(passwd, passwordEncryptor);
@@ -272,7 +272,7 @@ public class Merlin extends CryptoBase {
             trustStoreLocation = trustStoreLocation.trim();
 
             try (InputStream is = loadInputStream(loader, trustStoreLocation)) {
-                String passwd = properties.getProperty(prefix + TRUSTSTORE_PASSWORD, "changeit");
+                String passwd = properties.getProperty(prefix + TRUSTSTORE_PASSWORD);
                 if (passwd != null) {
                     passwd = passwd.trim();
                     passwd = decryptPassword(passwd, passwordEncryptor);
@@ -556,10 +556,10 @@ public class Merlin extends CryptoBase {
      */
     public X509Certificate[] getX509Certificates(CryptoType cryptoType) throws WSSecurityException {
         if (cryptoType == null) {
-            return null;
+            return new X509Certificate[0];
         }
         CryptoType.TYPE type = cryptoType.getType();
-        X509Certificate[] certs = null;
+        X509Certificate[] certs = new X509Certificate[0];
         switch (type) {
         case ISSUER_SERIAL:
             certs = getX509Certificates(cryptoType.getIssuer(), cryptoType.getSerial());
@@ -790,7 +790,7 @@ public class Merlin extends CryptoBase {
             // If a certificate has been found, the certificates must be compared
             // to ensure against phony DNs (compare encoded form including signature)
             //
-            if (foundCerts != null && foundCerts[0] != null && foundCerts[0].equals(certs[0])) {
+            if (foundCerts != null && foundCerts.length > 0 && foundCerts[0] != null && foundCerts[0].equals(certs[0])) {
                 try {
                     certs[0].checkValidity();
                 } catch (CertificateExpiredException | CertificateNotYetValidException e) {
@@ -1085,7 +1085,7 @@ public class Merlin extends CryptoBase {
         }
 
         if (certs == null || certs.length == 0) {
-            return null;
+            return new X509Certificate[0];
         }
 
         return Arrays.copyOf(certs, certs.length, X509Certificate[].class);
@@ -1173,7 +1173,7 @@ public class Merlin extends CryptoBase {
         }
 
         if (certs == null || certs.length == 0) {
-            return null;
+            return new X509Certificate[0];
         }
 
         return Arrays.copyOf(certs, certs.length, X509Certificate[].class);
@@ -1254,7 +1254,7 @@ public class Merlin extends CryptoBase {
         }
 
         if (certs == null || certs.length == 0) {
-            return null;
+            return new X509Certificate[0];
         }
 
         return Arrays.copyOf(certs, certs.length, X509Certificate[].class);
@@ -1329,7 +1329,7 @@ public class Merlin extends CryptoBase {
         }
 
         if (certs == null || certs.isEmpty()) {
-            return null;
+            return new X509Certificate[0];
         }
 
         // We just choose the first entry
@@ -1362,7 +1362,7 @@ public class Merlin extends CryptoBase {
      */
     private X509Certificate[] getX509Certificates(String identifier) throws WSSecurityException {
         if (identifier == null) {
-            return null;
+            return new X509Certificate[0];
         }
         Certificate[] certs = null;
         try {
@@ -1390,7 +1390,7 @@ public class Merlin extends CryptoBase {
             }
 
             if (certs == null) {
-                return null;
+                return new X509Certificate[0];
             }
         } catch (KeyStoreException e) {
             throw new WSSecurityException(WSSecurityException.ErrorCode.FAILURE, e, "keystore");
@@ -1555,7 +1555,7 @@ public class Merlin extends CryptoBase {
 
                 Certificate[] certs = store.getCertificateChain(alias);
                 if (certs == null || certs.length == 0) {
-                    // no cert chain, so lets check if getCertificate gives us a  result.
+                    // no cert chain, so lets check if getCertificate gives us a result.
                     Certificate retrievedCert = store.getCertificate(alias);
                     if (retrievedCert != null) {
                         certs = new Certificate[]{retrievedCert};
@@ -1580,7 +1580,7 @@ public class Merlin extends CryptoBase {
 
                 Certificate[] certs = store.getCertificateChain(alias);
                 if (certs == null || certs.length == 0) {
-                    // no cert chain, so lets check if getCertificate gives us a  result.
+                    // no cert chain, so lets check if getCertificate gives us a result.
                     Certificate retrievedCert = store.getCertificate(alias);
                     if (retrievedCert != null) {
                         certs = new Certificate[]{retrievedCert};
