@@ -117,7 +117,7 @@ public class Encryptor {
                 callbackLookup = new DOMCallbackLookup(doc);
             }
             List<Element> elementsToEncrypt =
-                WSSecurityUtil.findElements(encPart, callbackLookup, doc);
+                WSSecurityUtil.findElements(encPart, callbackLookup);
             if (elementsToEncrypt == null || elementsToEncrypt.isEmpty()) {
                 if (!encPart.isRequired()) {
                     continue;
@@ -593,13 +593,13 @@ public class Encryptor {
     public void setWsDocInfo(WSDocInfo wsDocInfo) {
         this.wsDocInfo = wsDocInfo;
     }
-    
+
     public boolean isOmitAttachmentKeyInfo() {
         return omitAttachmentKeyInfo;
     }
 
     public void setOmitAttachmentKeyInfo(boolean omitAttachmentKeyInfo) {
-         this.omitAttachmentKeyInfo = omitAttachmentKeyInfo;
+        this.omitAttachmentKeyInfo = omitAttachmentKeyInfo;
     }
 
 }
