@@ -19,20 +19,37 @@
 
 package org.apache.wss4j.dom.message;
 
-import java.security.InvalidAlgorithmParameterException;
-import java.security.InvalidKeyException;
-import java.security.Key;
-import java.security.NoSuchProviderException;
-import java.security.Provider;
-import java.security.PublicKey;
-import java.security.cert.X509Certificate;
-import java.security.spec.MGF1ParameterSpec;
+import org.apache.wss4j.common.WSS4JConstants;
+import org.apache.wss4j.common.crypto.Crypto;
+import org.apache.wss4j.common.crypto.CryptoType;
+import org.apache.wss4j.common.ext.WSPasswordCallback;
+import org.apache.wss4j.common.ext.WSSecurityException;
+import org.apache.wss4j.common.token.*;
+import org.apache.wss4j.common.util.AttachmentUtils;
+import org.apache.wss4j.common.util.KeyUtils;
+import org.apache.wss4j.dom.WSConstants;
+import org.apache.wss4j.dom.handler.RequestData;
+import org.apache.wss4j.dom.util.WSSecurityUtil;
+import org.apache.xml.security.encryption.XMLCipherUtil;
+import org.apache.xml.security.encryption.XMLEncryptionException;
+import org.apache.xml.security.encryption.keys.content.AgreementMethodImpl;
+import org.apache.xml.security.encryption.params.ConcatKDFParams;
+import org.apache.xml.security.encryption.params.HKDFParams;
+import org.apache.xml.security.encryption.params.KeyAgreementParameters;
+import org.apache.xml.security.encryption.params.KeyDerivationParameters;
+import org.apache.xml.security.exceptions.XMLSecurityException;
+import org.apache.xml.security.stax.ext.XMLSecurityConstants;
+import org.apache.xml.security.stax.impl.util.IDGenerator;
+import org.apache.xml.security.utils.Constants;
+import org.apache.xml.security.utils.XMLUtils;
+import org.w3c.dom.Document;
+import org.w3c.dom.Element;
+import org.w3c.dom.Text;
 
 import javax.crypto.Cipher;
 import javax.crypto.IllegalBlockSizeException;
 import javax.crypto.SecretKey;
 import javax.crypto.spec.OAEPParameterSpec;
-import javax.crypto.spec.PSource;
 import javax.security.auth.callback.Callback;
 import javax.xml.crypto.MarshalException;
 import javax.xml.crypto.dom.DOMStructure;
@@ -40,29 +57,8 @@ import javax.xml.crypto.dsig.XMLSignatureFactory;
 import javax.xml.crypto.dsig.keyinfo.KeyInfo;
 import javax.xml.crypto.dsig.keyinfo.KeyInfoFactory;
 import javax.xml.crypto.dsig.keyinfo.KeyValue;
-
-import org.apache.wss4j.common.crypto.Crypto;
-import org.apache.wss4j.common.crypto.CryptoType;
-import org.apache.wss4j.common.ext.WSPasswordCallback;
-import org.apache.wss4j.common.ext.WSSecurityException;
-import org.apache.wss4j.common.token.BinarySecurity;
-import org.apache.wss4j.common.token.DOMX509Data;
-import org.apache.wss4j.common.token.DOMX509IssuerSerial;
-import org.apache.wss4j.common.token.Reference;
-import org.apache.wss4j.common.token.SecurityTokenReference;
-import org.apache.wss4j.common.token.X509Security;
-import org.apache.wss4j.common.util.AttachmentUtils;
-import org.apache.wss4j.common.util.KeyUtils;
-import org.apache.wss4j.dom.WSConstants;
-import org.apache.wss4j.dom.handler.RequestData;
-import org.apache.wss4j.dom.util.WSSecurityUtil;
-import org.apache.xml.security.algorithms.JCEMapper;
-import org.apache.xml.security.stax.impl.util.IDGenerator;
-import org.apache.xml.security.utils.Constants;
-import org.apache.xml.security.utils.XMLUtils;
-import org.w3c.dom.Document;
-import org.w3c.dom.Element;
-import org.w3c.dom.Text;
+import java.security.*;
+import java.security.cert.X509Certificate;
 
 /**
  * Builder class to build an EncryptedKey.
@@ -83,6 +79,26 @@ public class WSSecEncryptedKey extends WSSecBase {
      */
     private String keyEncAlgo = WSConstants.KEYTRANSPORT_RSAOAEP;
 
+    /**
+     * Key agreement method algorithm used to encrypt the transport key.
+     * Example for ECDH-ES: http://www.w3.org/2009/xmlenc11#ECDH-ES
+     * and xec example: X25519: http://www.w3.org/2021/04/xmldsig-more#x25519,
+     *  x448: http://www.w3.org/2021/04/xmldsig-more#x448
+     */
+    private String keyAgreementMethod;
+
+    /**
+     * Method to derive the key to be used to encrypt the data with the Key keyAgreementMethod
+     *
+     */
+    private String keyDerivationMethod = WSS4JConstants.KEYDERIVATION_HKDF;
+
+
+    /**
+     * The Key Derivation Parameters for the with the Key keyAgreementMethod
+     */
+    private KeyDerivationParameters keyDerivationParameters;
+
     /**
      * Digest Algorithm to be used with RSA-OAEP. The default is SHA-1 (which is not
      * written out unless it is explicitly configured).
@@ -134,7 +150,7 @@ public class WSSecEncryptedKey extends WSSecBase {
     private String encryptedKeySHA1;
 
     protected boolean omitAttachmentKeyInfo;
-    
+
     public WSSecEncryptedKey(WSSecHeader securityHeader) {
         super(securityHeader);
     }
@@ -175,7 +191,6 @@ public class WSSecEncryptedKey extends WSSecBase {
     public void prepare(Crypto crypto, SecretKey symmetricKey) throws WSSecurityException  {
         this.prepare(crypto, symmetricKey, null);
     }
-    
     /**
      * Create the EncryptedKey Element for inclusion in the security header, by encrypting the
      * symmetricKey parameter using either a public key or certificate that is set on the class,
@@ -205,10 +220,10 @@ public class WSSecEncryptedKey extends WSSecBase {
             X509Certificate remoteCert = useThisCert;
 
             boolean useSymmetricKey = crypto != null 
-                    && crypto.getKeyStore() != null 
-                    && crypto.getKeyStore().getType() != null 
-                    && crypto.getKeyStore().getType().equals("JCEKS")
-                    && data != null;
+                && crypto.getKeyStore() != null 
+                && crypto.getKeyStore().getType() != null 
+                && crypto.getKeyStore().getType().equals("JCEKS")
+                && data != null;
 
             if (remoteCert == null && !useSymmetricKey) {
                 CryptoType cryptoType = new CryptoType(CryptoType.TYPE.ALIAS);
@@ -229,25 +244,31 @@ public class WSSecEncryptedKey extends WSSecBase {
                 remoteCert = certs[0];
             }
 
-            Key kek = null;
-            
-            if (useSymmetricKey) {
-                try {
-                    WSPasswordCallback pwCb = new WSPasswordCallback(user, WSPasswordCallback.SECRET_KEY);
-                    data.getCallbackHandler().handle(new Callback[]{pwCb});
-                    
-                    kek = crypto.getKeyStore().getKey(user, pwCb.getPassword().toCharArray());
-                } catch (Exception e) {
-                    throw new WSSecurityException(
+            Key kek;
+            KeyAgreementParameters dhSpec = null;
+            if (isKeyAgreementConfigured(keyAgreementMethod)) {
+                // generate ephemeral keys the key must match receivers keys
+                dhSpec = buildKeyAgreementParameter(remoteCert.getPublicKey());
+                kek = generateEncryptionKey(dhSpec);
+            } else {
+                if (useSymmetricKey) {
+                    try {
+                        WSPasswordCallback pwCb = new WSPasswordCallback(user, WSPasswordCallback.SECRET_KEY);
+                        data.getCallbackHandler().handle(new Callback[]{pwCb});
+
+                        kek = crypto.getKeyStore().getKey(user, pwCb.getPassword().toCharArray());
+                    } catch (Exception e) {
+                        throw new WSSecurityException(
                             WSSecurityException.ErrorCode.FAILURE,
                             "noSymmetricKeyFound",
                             new Object[] {user, "encryption"});
+                    }
+                } else { 
+                    kek = remoteCert.getPublicKey();
                 }
-            } else {
-                kek = remoteCert.getPublicKey();
             }
 
-            createEncryptedKeyElement(remoteCert, crypto);
+            createEncryptedKeyElement(remoteCert, crypto, dhSpec);
             byte[] encryptedEphemeralKey = encryptSymmetricKey(kek, symmetricKey);
             addCipherValueElement(encryptedEphemeralKey);
         }
@@ -272,21 +293,28 @@ public class WSSecEncryptedKey extends WSSecBase {
     }
 
     /**
-     * Now we need to setup the EncryptedKey header block:
+     * Now we need to set up the EncryptedKey header block:
      *  1) create a EncryptedKey element and set a wsu:Id for it
-     *  2) Generate ds:KeyInfo element, this wraps the wsse:SecurityTokenReference
-     *  3) Create and set up the SecurityTokenReference according to the keyIdentifier parameter
+     *  2) Generate ds:KeyInfo element
+     *  3) Create and set up the ds:KeyInfo child element - this can either be a SecurityTokenReference or X509Data/X509SKI
      *  4) Create the CipherValue element structure and insert the encrypted session key
      */
-    protected void createEncryptedKeyElement(X509Certificate remoteCert, Crypto crypto) throws WSSecurityException {
+    protected void createEncryptedKeyElement(X509Certificate remoteCert, Crypto crypto, KeyAgreementParameters dhSpec)
+            throws WSSecurityException {
         encryptedKeyElement = createEncryptedKey(getDocument(), keyEncAlgo);
-        if (encKeyId == null || encKeyId.length() == 0) {
+        if (encKeyId == null || encKeyId.isEmpty()) {
             encKeyId = IDGenerator.generateID("EK-");
         }
         encryptedKeyElement.setAttributeNS(null, "Id", encKeyId);
 
         if (customEKKeyInfoElement != null) {
             encryptedKeyElement.appendChild(getDocument().adoptNode(customEKKeyInfoElement));
+        } else if (keyIdentifierType == WSConstants.X509_SKI) {
+            DOMX509SKI x509SKI = new DOMX509SKI(getDocument(), remoteCert);
+            DOMX509Data x509Data = new DOMX509Data(getDocument(), x509SKI);
+
+            Element keyInfoElement = createKeyInfoElement(x509Data.getElement(), dhSpec);
+            encryptedKeyElement.appendChild(keyInfoElement);
         } else {
             SecurityTokenReference secToken = new SecurityTokenReference(getDocument());
             if (addWSUNamespace) {
@@ -362,7 +390,7 @@ public class WSSecEncryptedKey extends WSSecBase {
                     refCustd.setValueType(customEKTokenValueType);
                 } else if (WSConstants.WSS_SAML2_KI_VALUE_TYPE.equals(customEKTokenValueType)) {
                     secToken.addTokenType(WSConstants.WSS_SAML2_TOKEN_TYPE);
-                }  else if (WSConstants.WSS_ENC_KEY_VALUE_TYPE.equals(customEKTokenValueType)) {
+                } else if (WSConstants.WSS_ENC_KEY_VALUE_TYPE.equals(customEKTokenValueType)) {
                     secToken.addTokenType(WSConstants.WSS_ENC_KEY_VALUE_TYPE);
                     refCustd.setValueType(customEKTokenValueType);
                 } else {
@@ -389,17 +417,47 @@ public class WSSecEncryptedKey extends WSSecBase {
                 throw new WSSecurityException(WSSecurityException.ErrorCode.FAILURE, "unsupportedKeyId",
                                               new Object[] {keyIdentifierType});
             }
-            Element keyInfoElement =
-                getDocument().createElementNS(
-                    WSConstants.SIG_NS, WSConstants.SIG_PREFIX + ":" + WSConstants.KEYINFO_LN
-                );
-            keyInfoElement.setAttributeNS(
-                WSConstants.XMLNS_NS, "xmlns:" + WSConstants.SIG_PREFIX, WSConstants.SIG_NS
-            );
-            keyInfoElement.appendChild(secToken.getElement());
+
+            Element keyInfoElement = createKeyInfoElement(secToken.getElement(), dhSpec);
             encryptedKeyElement.appendChild(keyInfoElement);
         }
+    }
 
+    /**
+     * Method builds and returns a ds:KeyInfo element wrapping the provided child element.
+     */
+    private Element createKeyInfoElement(Element childElement, KeyAgreementParameters dhSpec) throws WSSecurityException {
+        Element keyInfoElement =
+                getDocument().createElementNS(
+                        WSConstants.SIG_NS, WSConstants.SIG_PREFIX + ":" + WSConstants.KEYINFO_LN
+                );
+        keyInfoElement.setAttributeNS(
+                WSConstants.XMLNS_NS, "xmlns:" + WSConstants.SIG_PREFIX, WSConstants.SIG_NS
+        );
+        if (isKeyAgreementConfigured(keyAgreementMethod)) {
+            try {
+                AgreementMethodImpl agreementMethod = new AgreementMethodImpl(getDocument(), dhSpec);
+                agreementMethod.getRecipientKeyInfo().addUnknownElement(childElement);
+                Element agreementMethodElement = agreementMethod.getElement();
+                keyInfoElement.appendChild(agreementMethodElement);
+            } catch (XMLSecurityException e) {
+                throw new WSSecurityException(WSSecurityException.ErrorCode.FAILURE, "unsupportedKeyId",
+                                              new Object[] {keyIdentifierType});
+            }
+
+        } else {
+            keyInfoElement.appendChild(childElement);
+        }
+        return keyInfoElement;
+    }
+
+    /**
+     * Method verifies is the key agreement method is configured(not empty)
+     * @param keyAgreementMethod the key agreement method
+     * @return true if the key agreement method is not empty else false
+     */
+    private boolean isKeyAgreementConfigured(String keyAgreementMethod) {
+         return keyAgreementMethod != null && !keyAgreementMethod.isEmpty();
     }
 
     private void addIssuerSerial(X509Certificate remoteCert, SecurityTokenReference secToken, boolean isCommaDelimited)
@@ -428,7 +486,7 @@ public class WSSecEncryptedKey extends WSSecBase {
      */
     protected void createEncryptedKeyElement(Key key) throws WSSecurityException {
         encryptedKeyElement = createEncryptedKey(getDocument(), keyEncAlgo);
-        if (encKeyId == null || encKeyId.length() == 0) {
+        if (encKeyId == null || encKeyId.isEmpty()) {
             encKeyId = IDGenerator.generateID("EK-");
         }
         encryptedKeyElement.setAttributeNS(null, "Id", encKeyId);
@@ -467,7 +525,7 @@ public class WSSecEncryptedKey extends WSSecBase {
                         refCustd.setValueType(customEKTokenValueType);
                     } else if (WSConstants.WSS_SAML2_KI_VALUE_TYPE.equals(customEKTokenValueType)) {
                         secToken.addTokenType(WSConstants.WSS_SAML2_TOKEN_TYPE);
-                    }  else if (WSConstants.WSS_ENC_KEY_VALUE_TYPE.equals(customEKTokenValueType)) {
+                    } else if (WSConstants.WSS_ENC_KEY_VALUE_TYPE.equals(customEKTokenValueType)) {
                         secToken.addTokenType(WSConstants.WSS_ENC_KEY_VALUE_TYPE);
                         refCustd.setValueType(customEKTokenValueType);
                     } else {
@@ -546,35 +604,131 @@ public class WSSecEncryptedKey extends WSSecBase {
         }
     }
 
-    protected byte[] encryptSymmetricKey(Key encryptingKey, SecretKey keyToBeEncrypted)
+    /**
+     * Method builds the KeyAgreementParameterSpec for the ECDH-ES, X25519 or X448
+     * Key Agreement Method using the recipient's public key and preconfigured values:
+     * keyEncAlgo, digestAlgo and keyAgreementMethod. If the keyDerivationParameters
+     * are not set, the default values for the key derivation method are used.
+     *
+     * @param recipientPublicKey the recipient's public key
+     * @return KeyAgreementParameterSpec the {@link java.security.spec.AlgorithmParameterSpec} for generating the
+     * key for encrypting transport key and generating XML elements.
+     *
+     * @throws WSSecurityException if the KeyAgreementParameterSpec cannot be created due to
+     * invalid key agreement method or key derivation method and wrap algorithm not supported
+     */
+    private KeyAgreementParameters buildKeyAgreementParameter(PublicKey recipientPublicKey)
+            throws WSSecurityException {
+        KeyAgreementParameters dhSpec;
+        try {
+            int keyBitLength = org.apache.xml.security.utils.KeyUtils.getAESKeyBitSizeForWrapAlgorithm(keyEncAlgo);
+            KeyDerivationParameters kdf = keyDerivationParameters;
+            if (keyDerivationParameters == null) {
+                LOG.debug("Set default KeyDerivationParameters for key derivation method: [{}]",
+                        keyDerivationMethod);
+                kdf = buildDefaultKeyDerivationParameters(keyBitLength);
+            }
+            KeyPair dhKeyPair = org.apache.xml.security.utils.KeyUtils.generateEphemeralDHKeyPair(recipientPublicKey, null);
+            dhSpec = XMLCipherUtil.constructAgreementParameters(keyAgreementMethod,
+                    KeyAgreementParameters.ActorType.ORIGINATOR, kdf, null, recipientPublicKey);
+            dhSpec.setOriginatorKeyPair(dhKeyPair);
+        } catch (XMLEncryptionException e) {
+            throw new WSSecurityException(
+                    WSSecurityException.ErrorCode.FAILED_ENCRYPTION, e
+            );
+        }
+        return dhSpec;
+    }
+
+    /**
+     * Method builds the KeyDerivationParameters for keyDerivationMethod with default values.
+     * The default values for the key derivation method are:
+     * <ul>
+     *   <li>ConcatKDF
+     *     <ul>
+     *       <li> DigestAlgorithm: "http://www.w3.org/2001/04/xmlenc#sha256"</li>
+     *       <li> AlgorithmID: "0000"</li>
+     *       <li> PartyUInfo: ""</li>
+     *       <li> PartyVInfo: ""</li>
+     *       <li> SuppPubInfo: null</li>
+     *       <li> SuppPrivInfo: null</li>
+     *     </ul>
+     *   <li>HKDF: SHA-256
+     *     <ul>
+     *       <li> PRF: http://www.w3.org/2001/04/xmldsig-more#hmac-sha256 </li>
+     *       <li> Salt: random 256 bit value</li>
+     *       <li> Info: null</li>
+     *     </ul>
+     *   </li>
+     * </ul>
+     *
+     * @param keyBitLength the length of the derived key in bits
+     * @return KeyDerivationParameters the {@link KeyDerivationParameters} for generating the
+     * key for encrypting transport key and generating XML elements.
+     * @throws WSSecurityException if the KeyDerivationParameters cannot be created
+     */
+    private KeyDerivationParameters buildDefaultKeyDerivationParameters(int keyBitLength) throws WSSecurityException {
+
+        switch (keyDerivationMethod) {
+            case WSS4JConstants.KEYDERIVATION_CONCATKDF:
+                return ConcatKDFParams.createBuilder(keyBitLength, WSConstants.SHA256)
+                        .algorithmID("0000")
+                        .partyUInfo("")
+                        .partyVInfo("")
+                        .build();
+            case WSS4JConstants.KEYDERIVATION_HKDF:
+                // use semi random value for salt.
+                // rfc5869: Yet, even a salt value of less quality (shorter in
+                //   size or with limited entropy) may still make a significant
+                //   contribution to the security of the output keying material
+                byte[] semiRandom;
+                try { 
+                    int length = keyBitLength / 8;
+                    semiRandom = XMLSecurityConstants.generateBytes(length);
+                } catch (Exception ex) {
+                    throw new WSSecurityException(WSSecurityException.ErrorCode.FAILURE, ex,
+                            "empty", new Object[] {"Error in generating secret bytes " }
+                    );
+                }
+                return HKDFParams.createBuilder(keyBitLength, WSS4JConstants.HMAC_SHA256)
+                        .salt(semiRandom)
+                        .info(null)
+                        .build();
+            default:
+                throw new WSSecurityException(
+                        WSSecurityException.ErrorCode.FAILED_ENCRYPTION, "unsupportedKeyDerivationMethod",
+                        new Object[]{keyDerivationMethod}
+                );
+        }
+    }
+
+
+    /**
+     * Method generates the key for encrypting the transport key using the KeyAgreementParameterSpec
+     *
+     * @param keyAgreementParameter the {@link KeyAgreementParameters} for generating the secret key
+     * @return SecretKey the secret key for encrypting the transport key
+     * @throws WSSecurityException if the secret key cannot be generated
+     */
+    private SecretKey generateEncryptionKey(KeyAgreementParameters keyAgreementParameter) throws WSSecurityException {
+        try {
+            // derive the key for encryption of the transport key
+            return org.apache.xml.security.utils.KeyUtils.aesWrapKeyWithDHGeneratedKey(keyAgreementParameter);
+        } catch (XMLEncryptionException e) {
+            throw new WSSecurityException(
+                    WSSecurityException.ErrorCode.FAILED_ENCRYPTION, e
+            );
+        }
+    }
+
+    private byte[] encryptSymmetricKey(Key encryptingKey, SecretKey keyToBeEncrypted)
         throws WSSecurityException {
         Cipher cipher = KeyUtils.getCipherInstance(keyEncAlgo);
         try {
             OAEPParameterSpec oaepParameterSpec = null;
             if (WSConstants.KEYTRANSPORT_RSAOAEP.equals(keyEncAlgo)
                     || WSConstants.KEYTRANSPORT_RSAOAEP_XENC11.equals(keyEncAlgo)) {
-                String jceDigestAlgorithm = "SHA-1";
-                if (digestAlgo != null) {
-                    jceDigestAlgorithm = JCEMapper.translateURItoJCEID(digestAlgo);
-                }
-
-                MGF1ParameterSpec mgf1ParameterSpec = new MGF1ParameterSpec("SHA-1");
-                if (WSConstants.KEYTRANSPORT_RSAOAEP_XENC11.equals(keyEncAlgo)) {
-                    if (WSConstants.MGF_SHA224.equals(mgfAlgo)) {
-                        mgf1ParameterSpec = new MGF1ParameterSpec("SHA-224");
-                    } else if (WSConstants.MGF_SHA256.equals(mgfAlgo)) {
-                        mgf1ParameterSpec = new MGF1ParameterSpec("SHA-256");
-                    } else if (WSConstants.MGF_SHA384.equals(mgfAlgo)) {
-                        mgf1ParameterSpec = new MGF1ParameterSpec("SHA-384");
-                    } else if (WSConstants.MGF_SHA512.equals(mgfAlgo)) {
-                        mgf1ParameterSpec = new MGF1ParameterSpec("SHA-512");
-                    }
-                }
-
-                oaepParameterSpec =
-                    new OAEPParameterSpec(
-                        jceDigestAlgorithm, "MGF1", mgf1ParameterSpec, PSource.PSpecified.DEFAULT
-                    );
+                oaepParameterSpec = XMLCipherUtil.constructOAEPParameters(keyEncAlgo, digestAlgo, mgfAlgo, null);
             }
             if (oaepParameterSpec == null) {
                 cipher.init(Cipher.WRAP_MODE, encryptingKey);
@@ -628,7 +782,8 @@ public class WSSecEncryptedKey extends WSSecBase {
             doc.createElementNS(WSConstants.ENC_NS, WSConstants.ENC_PREFIX + ":EncryptionMethod");
         encryptionMethod.setAttributeNS(null, "Algorithm", keyTransportAlgo);
 
-        if (digestAlgo != null) {
+        if ((WSConstants.KEYTRANSPORT_RSAOAEP_XENC11.equals(keyEncAlgo) || WSConstants.KEYTRANSPORT_RSAOAEP.equals(
+                keyEncAlgo)) && digestAlgo != null) {
             Element digestElement =
                 XMLUtils.createElementInSignatureSpace(doc, Constants._TAG_DIGESTMETHOD);
             digestElement.setAttributeNS(null, "Algorithm", digestAlgo);
@@ -773,8 +928,32 @@ public class WSSecEncryptedKey extends WSSecBase {
         return keyEncAlgo;
     }
 
+    public String getKeyAgreementMethod() {
+        return keyAgreementMethod;
+    }
+
+    public void setKeyAgreementMethod(String keyAgreementMethod) {
+        this.keyAgreementMethod = keyAgreementMethod;
+    }
+
+    public String getKeyDerivationMethod() {
+        return keyDerivationMethod;
+    }
+
+    public void setKeyDerivationMethod(String keyDerivationMethod) {
+        this.keyDerivationMethod = keyDerivationMethod;
+    }
+
+    public KeyDerivationParameters getKeyDerivationParameters() {
+        return keyDerivationParameters;
+    }
+
+    public void setKeyDerivationParameters(KeyDerivationParameters keyDerivationParameters) {
+        this.keyDerivationParameters = keyDerivationParameters;
+    }
+
     /**
-     * Get the id of the BSt generated  during <code>prepare()</code>.
+     * Get the id of the BSt generated during <code>prepare()</code>.
      *
      * @return Returns the the value of wsu:Id attribute of the
      * BinaruSecurityToken element.
@@ -795,10 +974,7 @@ public class WSSecEncryptedKey extends WSSecBase {
     }
 
     public boolean isCertSet() {
-        if (useThisCert == null) {
-            return false;
-        }
-        return true;
+        return useThisCert != null;
     }
 
     public void setCustomEKTokenValueType(String customEKTokenValueType) {
