@@ -3,8 +3,11 @@
 -- GovWay Configurazione
 
 -- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
+-- DROP INDEX index_users_ricerche_1;
 -- DROP INDEX index_users_servizi_1;
 -- DROP INDEX index_users_soggetti_1;
+DROP TABLE users_ricerche_init_seq;
+DROP TABLE users_ricerche;
 DROP TABLE users_servizi_init_seq;
 DROP TABLE users_servizi;
 DROP TABLE users_soggetti_init_seq;
@@ -15,6 +18,7 @@ DROP TABLE users_stati_init_seq;
 DROP TABLE users_stati;
 DROP TABLE users_init_seq;
 DROP TABLE users;
+DROP SEQUENCE seq_users_ricerche;
 DROP SEQUENCE seq_users_servizi;
 DROP SEQUENCE seq_users_soggetti;
 DROP SEQUENCE seq_users_password;
@@ -22,21 +26,6 @@ DROP SEQUENCE seq_users_stati;
 DROP SEQUENCE seq_users;
 
 
--- govway
-		  		
--- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
--- DROP INDEX parameters_index;
--- DROP INDEX operations_gdo;
--- DROP INDEX operations_precedenti;
--- DROP INDEX operations_superuser;
-DROP TABLE parameters_init_seq;
-DROP TABLE parameters;
-DROP TABLE operations_init_seq;
-DROP TABLE operations;
-DROP SEQUENCE seq_parameters;
-DROP SEQUENCE seq_operations;
-
-
 -- govway
 		  		
 -- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
